/**
 * Copyright (C) 2010 OSGi fuer Praktiker <info@osgi-buch.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package biz.gossipmonger.gatekeeper;

import java.io.File;
import java.util.Dictionary;
import java.util.Hashtable;

import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.osgi.service.event.Event;
import org.osgi.service.event.EventConstants;
import org.osgi.service.event.EventHandler;

public class GateKeeper implements BundleActivator, EventHandler {
  private File watchedDir = new File("render_input");

  public void start(BundleContext ctx) throws Exception {
    String[] topics = new String[] { "biz/gossipmonger/jobtimer" };
    Dictionary<String, Object> dict = new Hashtable<String, Object>();
    dict.put(EventConstants.EVENT_TOPIC, topics);
    ctx.registerService(EventHandler.class.getName(), this, dict);
  }
  
  public void stop(BundleContext ctx) throws Exception {
  }
  
  public void handleEvent(Event event) {
    prepareWatchedDir();
    String list[] = watchedDir.list();
    System.out.println("GateKeeper found " + list.length + " entries in " + watchedDir);
  }
  
  private void prepareWatchedDir() {
    if (!watchedDir.exists()) {
      if (!watchedDir.mkdirs()) {
        throw new RuntimeException("GateKeeper can't create folder " + watchedDir);
      }
      System.out.println("GateKeeper created watched directory " + watchedDir.getAbsolutePath());
    }
    if (!watchedDir.isDirectory()) {
      throw new RuntimeException("GateKeeper can't watch " + watchedDir + " because it's no directory");
    }
  }
}
