/**
 * Copyright (C) 2010 OSGi fuer Praktiker <info@osgi-buch.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package biz.gossipmonger.test.worker;

import static org.ops4j.pax.exam.CoreOptions.mavenBundle;
import static org.ops4j.pax.exam.CoreOptions.options;
import static org.ops4j.pax.exam.CoreOptions.provision;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.net.URL;

import org.junit.Assert;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.ops4j.pax.exam.Option;
import org.ops4j.pax.exam.junit.Configuration;
import org.ops4j.pax.exam.junit.JUnit4TestRunner;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;

import biz.gossipmonger.worker.WorkerService;
@RunWith(JUnit4TestRunner.class)
public class SimpleWorkerServiceTest {
  @Configuration
  public static Option[] configure() {
    return options(
      provision(
        // Infrastructure bundles
        mavenBundle().groupId("org.osgi").artifactId("org.osgi.compendium"),
        mavenBundle().groupId("org.apache.felix").artifactId("org.apache.felix.eventadmin"),
        mavenBundle().groupId("org.apache.felix").artifactId("org.apache.felix.scr"),
        // Project bundles
        mavenBundle().groupId("biz.gossipmonger").artifactId("biz.gossipmonger.worker-api").versionAsInProject(),
        mavenBundle().groupId("biz.gossipmonger").artifactId("biz.gossipmonger.worker-impl").versionAsInProject(),
        mavenBundle().groupId("biz.gossipmonger").artifactId("biz.gossipmonger.enunciator").versionAsInProject(),
        mavenBundle().groupId("biz.gossipmonger.com.itextpdf").artifactId("biz.gossipmonger.com.itextpdf.itext").versionAsInProject()
      )
    );
  }


  @Test
  public void workerServiceResultExists(final BundleContext bundleContext) {
    ServiceReference ref = bundleContext.getServiceReference(biz.gossipmonger.worker.WorkerService.class.getName());
    Assert.assertNotNull(ref);
    WorkerService worker = (WorkerService) bundleContext.getService(ref);
    Assert.assertNotNull(worker);
    try {
      String filename = "test.txt";
      URL url = bundleContext.getBundle().getResource(filename);
      InputStream is = url.openStream();
      File file = worker.process(is, filename);
      Assert.assertNotNull(file);
      String filePath = file.getAbsolutePath();
      Assert.assertTrue(filePath + " does not exist", file.exists());
    } catch (IOException e) {
      e.printStackTrace();
      throw new RuntimeException(e);
    }
  }
}
